#
# spec file for package python-mitmproxy-wireguard
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname mitmproxy_wireguard
%{?sle15_python_module_pythons}
Name:           python-mitmproxy-wireguard
Version:        0.1.23
Release:        3.4
Summary:        WireGuard interface for mitmproxy
License:        MIT
URL:            https://github.com/decathorpe/mitmproxy_wireguard
Source0:        https://files.pythonhosted.org/packages/source/m/mitmproxy_wireguard/%{modname}-%{version}.tar.gz
# use `osc service disabledrun` to regenerate
Source2:        vendor.tar.zst
Source3:        cargo_config
BuildRequires:  %{python_module devel >= 3.7}
BuildRequires:  %{python_module maturin >= 0.13.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools-rust}
BuildRequires:  %{python_module wheel}
BuildRequires:  cargo >= 1.41.0
BuildRequires:  cargo-packaging
BuildRequires:  fdupes
BuildRequires:  libopenssl-devel
BuildRequires:  pkgconfig
BuildRequires:  python-rpm-macros
BuildRequires:  rust >= 1.58.0
BuildRequires:  zstd
# python-base is not enough, we need the _ssl module
Requires:       python >= 3.7
%python_subpackages

%description
Transparently proxy any device that can be configured as a WireGuard client!

%prep
%autosetup -a2 -p1 -n %{modname}-%{version}

mkdir -p .cargo
cp %{SOURCE3} .cargo/config
rm -fv .cargo/config.toml

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%{cargo_test}

%files %{python_files}
%license LICENSE
%doc CHANGELOG.md README.md
%{python_sitearch}/mitmproxy_wireguard
%{python_sitearch}/mitmproxy_wireguard-%{version}*-info

%changelog
* Mon Apr  8 2024 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequiring *-debuginfo sounds weird to start with: and since
  recently, that python-maturin does not even produce binaries
  anymore and thus also no debuginfo package.
* Mon Jan 29 2024 Dirk Müller <dmueller@suse.com>
- build for modern python stack
* Fri May  5 2023 Markéta Machová <mmachova@suse.com>
- Update to 0.1.23
  * Fix memory leak in TcpStream.read, which caused any bytes object returned by this method never to be garbage collected.
  * Run cleanup of TCP connection handler tasks eagerly instead of only at task shutdown.
  * Update to pyo3 v0.18.2, which includes a fix for a rare race condition.
  * Pin x25519-dalek dependency to =2.0.0-pre.1 to fix build issues with recent releases that contain breaking changes.
* Tue Dec 13 2022 Matej Cepl <mcepl@suse.com>
- Initial packaging effort of mitmproxy-wireguard version 0.1.19.
